@@ -1,11 +1,11 @@
 import numpy
 import xarray
 import matplotlib.pyplot as plt
-from configparser import ConfigParser
+import configparser 
+config = configparser.ConfigParser()
+config.read('lazyearth.ini')
+Cloud = (config['Cloud']['Fashcloud'])
 
-file = 'lazyearth.ini'
-config = ConfigParser()
-config.read(file)
 
 class objearth():
     def __init__(self,DataArray):
@@ -58,10 +58,8 @@ class objearth():
             print("Nonetype :",type(self.DataArray))
             
     def NDVI(self):
-        Nodata = int(config['Data']['Nodata'])
-        fractionconstant = float(config['Plot']['fractionnumber'])
-        red = xarray.where(self.DataArray.red==Nodata,numpy.nan,self.DataArray.red)
-        nir = xarray.where(self.DataArray.nir==Nodata,numpy.nan,self.DataArray.nir)
+        red = xarray.where(self.DataArray.red==-9999,numpy.nan,self.DataArray.red)
+        nir = xarray.where(self.DataArray.nir==-9999,numpy.nan,self.DataArray.nir)
         ndvi1 = (nir-red)/(nir+red).to_numpy()
         ndvi3 = numpy.clip(ndvi1,-1,1)
         im_ratio = ndvi3.shape[1]/ndvi3.shape[0]
@@ -69,14 +67,13 @@ class objearth():
         plt.xticks([]), plt.yticks([])
         plt.imshow(ndvi3,cmap='viridis')
         plt.clim(-1,1)
-        plt.colorbar(orientation="vertical",fraction=fractionconstant*im_ratio)
+        plt.colorbar(orientation="vertical",fraction=0.0378*im_ratio)
         plt.show()
         return ndvi3
 
     def percentcloud(self,Dataset):
-        Cloud = (config['Cloud']['Fashcloud'])
         self.Dataset = Dataset
-        FashCloud = Cloud
+        FashCloud = [352,480,944]
         dstest    = self.Dataset.pixel_qa
         dsnew     = xarray.where(dstest == FashCloud[0],numpy.nan,dstest)
         dsnew     = xarray.where(dsnew  == FashCloud[1],numpy.nan,dsnew)
@@ -85,6 +82,9 @@ class objearth():
         Allpixel  = int(self.Dataset.pixel_qa.count())
         Cloudpercent = (Cpixel/Allpixel)*100
         print("Percent Cloud : %.4f"%Cloudpercent,"%")
-   
+        print(Cloud)
+
+
+
     
 
